@@ -197,28 +197,53 @@ def run_projects():
 xserver_start_projects_script = """#!/usr/bin/python
 ### BEGIN INIT INFO
 # Provides: Hepochen
-# Default-start: 2 3 4 5
-# Default-Stop: 0 1 6
+# Default-start: 5
+# Default-Stop: 6
 # Short-Description: auto start xserver containers
 ### END INIT INFO
 
-import sys
+import sys,time
 from xserver.utils.docker_utils import print_docker_status
 from xserver.server.project import run_projects
+
 if __name__ == '__main__':
     args = sys.argv[1:]
-    if args and args[0] == 'start':
-        run_projects()
-    else:
+    if args and args[0] == 'status':
         print_docker_status()
+    else:
+        time.sleep(3)
+        run_projects()
+    try:
+        with open("/var/log/xserver_started.log", "a") as f:
+            f.write("%s: %s\n\n" % (time.time(), " ".join(sys.argv)))
+    except:
+        pass
 """
 
+
 # ls /etc/rc*.d/
-# update-rc.d -f started remove
+# update-rc.d -f started remove && rm /etc/rc95.d/*started
+# xserver install_started
+# update-rc.d started defaults 95
 def install_xserver_started():
     script_filepath = '/etc/init.d/started'
     write_file(script_filepath, xserver_start_projects_script)
     run_commands('chmod +x %s' % script_filepath)
 
-    run_commands('export LC_ALL="en_US.UTF-8"')
-    run_commands('update-rc.d started defaults 95') # 启动各项目容器的脚本
\ No newline at end of file
+    rc_local_filepath = "/etc/rc.d/rc.local"
+    try:
+        with open(rc_local_filepath, "rb") as f:
+            rc_local_content = f.read()
+    except:
+        rc_local_content = ""
+    start_cmd = "/etc/init.d/started start"
+    if start_cmd not in rc_local_content:
+        rc_local_content += "\n%s" % start_cmd
+        try:
+            with open(rc_local_filepath, 'wb') as f:
+                f.write(rc_local_content)
+            print_with_color(rc_local_content, color="green")
+        except:
+            print("failed to install started script for xserver")
+    #run_commands('export LC_ALL="en_US.UTF-8"')
+    #run_commands('update-rc.d started defaults 95') # 启动各项目容器的脚本
